SignTransactionsResult class
Sign Transactions Result
- Inheritance
-
- Object
- Serialisable
- SignTransactionsResult
Constructors
-
SignTransactionsResult({required List<
Base64EncodedSignedTransaction> signedPayloads}) -
The result of a successful
sign_transactionsrequest.const -
SignTransactionsResult.fromJson(Map<
String, dynamic> json) -
Creates an instance of
thisclass from the constructor parameters defined in thejsonobject.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signedPayloads
→ List<
Base64EncodedSignedTransaction> -
The corresponding base-64 encoded signed transactions of the request's
SignTransactionsParams.payloads.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialises
thisclass into a JSON object.override -
toJsonClean(
) → Map< String, dynamic> -
Returns the result of toJson, removing all
nullvalued entries.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited